import { TextRenderer, CellRenderer, GraphicsContext } from '@lumino/datagrid';
import { ViewBasedJSONModel } from './viewbasedjsonmodel';
import { DataGrid } from '@lumino/datagrid';
/**
 * A custom cell renderer for headers that provides a menu icon.
 */
export declare class HeaderRenderer extends TextRenderer {
    constructor(options: HeaderRenderer.IOptions);
    /**
     * Model getter.
     */
    get model(): ViewBasedJSONModel;
    /**
     * Draw the text for the cell.
     *
     * @param gc - The graphics context to use for drawing.
     *
     * @param config - The configuration data for the cell.
     */
    drawText(gc: GraphicsContext, config: CellRenderer.CellConfig): void;
    /**
     * Draw the filter icon for the cell
     *
     * @param gc - The graphics context to use for drawing.
     *
     * @param config - The configuration data for the cell.
     */
    drawFilterIcon(gc: GraphicsContext, config: CellRenderer.CellConfig): void;
    /**
     * Draw the ascending and descending sort icons for the cell
     *
     * @param gc - The graphics context to use for drawing.
     *
     * @param config - The configuration data for the cell.
     *
     * @param filterIconStart - The bottom right corner of drawing area.
     *
     * @param asc - Indicates whether to draw ascending or descending icon.
     */
    drawSortArrow(gc: GraphicsContext, config: CellRenderer.CellConfig, filterIconStart: number, asc: boolean): void;
    /**
     * Indicates the size of the menu icon, to support the current implementation
     * of hit testing.
     */
    static buttonSize: number;
    static iconHeight: number;
    static iconWidth: number;
    static buttonPadding: number;
    static iconSpacing: number;
    private _isLightTheme;
    private _grid;
}
/**
 * The namespace for the `HeaderRenderer` class statics.
 */
export declare namespace HeaderRenderer {
    /**
     * An options object for initializing a renderer.
     */
    interface IOptions {
        /**
         * The data model this renderer should get metadata from.
         */
        textOptions: TextRenderer.IOptions;
        isLightTheme: boolean;
        grid: DataGrid;
    }
}
