"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DataSource = void 0;
class DataSource {
    constructor(data, fields, schema, computeSchema = false) {
        this._data = Object.assign({}, data);
        if (computeSchema) {
            this._fields = fields;
            this._schema = this._createSchema(fields, schema);
        }
        else {
            this._fields = fields;
            this._schema = schema;
        }
        this._columns = Object.keys(this._data);
    }
    get data() {
        return this._data;
    }
    get fields() {
        return this._fields;
    }
    get schema() {
        return this._schema;
    }
    get length() {
        if (this._columns.length == 0) {
            return 0;
        }
        return this._data[this._columns[0]].length;
    }
    _createSchema(origFields, origSchema) {
        // Construct a new array of schema fields based on the keys in data.fields
        // Note: this accounts for how tuples/lists may be serialized into strings
        // in the case of multiIndex columns.
        const fields = [];
        origFields.forEach((val, i) => {
            const rows = Array.isArray(origSchema.fields[i].name)
                ? origSchema.fields[i].name
                : [origSchema.fields[i].name];
            const field = {
                name: Object.keys(val)[0],
                type: origSchema.fields[i].type,
                rows: rows,
            };
            fields.push(field);
        });
        // Updating the primary key to account for a multiIndex primary key.
        const primaryKey = origSchema.primaryKey.map((key) => {
            for (let i = 0; i < origSchema.fields.length; i++) {
                const curFieldKey = Array.isArray(key)
                    ? origSchema.fields[i].name[0]
                    : origSchema.fields[i].name;
                const newKey = Array.isArray(key) ? key[0] : key;
                if (curFieldKey == newKey) {
                    return Object.keys(origFields[i])[0];
                }
            }
            return 'unreachable';
        });
        return {
            primaryKey: primaryKey,
            primaryKeyUuid: origSchema.primaryKeyUuid,
            fields: fields,
        };
    }
}
exports.DataSource = DataSource;
//# sourceMappingURL=datasource.js.map