import { BasicMouseHandler, DataGrid } from '@lumino/datagrid';
import { ISignal } from '@lumino/signaling';
import { FeatherGrid } from './feathergrid';
export declare class MouseHandler extends BasicMouseHandler {
    /**
     * Construct a new datagrid mouse handler.
     *
     * @param grid - The FeatherGrid object for which mouse events are handled.
     */
    constructor(grid: FeatherGrid);
    /**
     * Handle the mouse down event for the data grid.
     *
     * @param grid - The data grid of interest.
     *
     * @param event - The mouse down event of interest.
     */
    onMouseDown(grid: DataGrid, event: MouseEvent): void;
    onMouseUp(grid: DataGrid, event: MouseEvent): void;
    get mouseIsDown(): boolean;
    get isResizing(): boolean;
    /**
     * A signal emitted when a grid cell is clicked.
     */
    get cellClicked(): ISignal<this, DataGrid.HitTestResult>;
    /**
     * Creates a CellConfig object from a hit region.
     */
    private static createCellConfigObject;
    private _grid;
    private _mouseIsDown;
    private _cellClicked;
}
